# System

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**uuid** | **str** |  | [optional] 
**name** | **str** | Name of the system | [optional] 
**object_type** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**elements** | **list[str]** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


